**********************************************************
*RecodeIncumbentGameData.do

*Generic recoding of incumbent game data from surveys fielded 
*on Mechanical Turk by Huber, Hill, and Lenz in March, 
*April, and May 2011.
**********************************************************

*Deflate token payments by denom to make coefficients more interpretable.
local denom = 100

****************************
*Aggregate payments for analysis.
****************************
egen payments1_16  = rowmean(pay1-pay16)
egen payments1_4   = rowmean(pay1-pay4)
egen payments5_8   = rowmean(pay5-pay8)
egen payments9_12  = rowmean(pay9-pay12)
egen payments13_16 = rowmean(pay13-pay16)
*Two different ways to create the average payment indicators.
if (1) {
  *Version one is blocked averages.
  gen  payavggt1200inrounds1_16 = (payments1_16 > 1200)
  gen  payavggt1200inrounds1_4 = (payments1_4 > 1200)
  gen  payavggt1200inrounds5_8 = (payments5_8 > 1200)
  gen  payavggt1200inrounds9_12 = (payments9_12 > 1200)
  gen  payavggt1200inrounds13_16 = (payments13_16 > 1200)
}
else {
  *Version two is overlapping averages.
}

*Use payments1_16 as base category, dropping payments 5_8.
drop payments5_8 payavggt1200inrounds5_8

*Value labels for payments1_16 for plots.
label define payments 6 "600" 8 "800" 10 "1000" 12 "1200" 14 "1400" 16 "1600" 18 "1800"
label values payments1_16 payments

****************************
*Retention decisions.
****************************
label variable keepallocator "Retain"
destring responsepostGameKeep, gen(keepallocator2)
label variable keepallocator2 "Retain"

****************************
*Generate payments for second retention decision as above.
****************************
egen keep2payments17_32  = rowmean(pay17-pay32)
egen keep2payments17_20  = rowmean(pay17-pay20)
egen keep2payments21_24   = rowmean(pay21-pay24)
egen keep2payments25_28  = rowmean(pay25-pay28)
egen keep2payments29_32 = rowmean(pay29-pay32)
*Two different ways to create the average payment indicators.
if (1) {
  *Version one is blocked averages.
  gen  keep2payavggt1200inrounds17_32 = (keep2payments17_32 > 1200)
  gen  keep2payavggt1200inrounds17_20 = (keep2payments17_20 > 1200)
  gen  keep2payavggt1200inrounds21_24 = (keep2payments21_24 > 1200)
  gen  keep2payavggt1200inrounds25_28 = (keep2payments25_28 > 1200)
  gen  keep2payavggt1200inrounds29_32 = (keep2payments29_32 > 1200)
}
else {
  *Version two is overlapping averages.
}

*Use keep2payments17_32 as base category, dropping keep2payments21_24.
drop keep2payments21_24 keep2payavggt1200inrounds21_24

****************************
*Change payment units to `denom's of tokens.
****************************
foreach var of varlist payments*_* keep2payments*_* lotterypay {
  replace `var' = `var'/`denom'
}
label variable lotterypay "Payment from Lottery (in `denom's of tokens)"

****************************
*Mean-deviated payments.
****************************
gen devpayments1_4   = (payments1_4-payments1_16)
gen devpayments9_12  = (payments9_12-payments1_16)
gen devpayments13_16 = (payments13_16-payments1_16)
label var devpayments1_4 "Average payment deviations in Rounds 1-4"
label var devpayments9_12 "Average payment deviations in Rounds 9-12"
label var devpayments13_16 "Average payment deviations in Rounds 13-16" 

****************************
*Intervention indicators.
****************************
levelsof intervention, local(ivalues)
local ctr 1
foreach i of local ivalues {
  gen interv_`ctr' = intervention == "`i'"
  label variable interv_`ctr' "`i'"
  local ctr = `ctr' + 1
}

****************************
*Generate interactions and labels.
****************************
foreach var of varlist payments*_* keep2payments*_* {
  local rounds = substr("`var'",strpos("`var'","ments")+5,5)
  local roundstring = subinstr("`rounds'","_","-",.)
  label variable `var' "Average Payment in Rounds `roundstring' (in `denom's of tokens)"
  local ctr 1
  foreach i of local ivalues {
    gen X`var'_`ctr' = `var'*(intervention == "`i'")
    label variable X`var'_`ctr' "Average Payment in Rounds `roundstring' * `i'"
    local ctr = `ctr' + 1
  }
}

foreach var of varlist payavggt1200inrounds* {
  local rounds = substr("`var'",strpos("`var'","rounds")+6,5)
  local roundstring = subinstr("`rounds'","_","-",.)
  label variable `var' "Average > 1200 in Rounds `roundstring'"
  local ctr 1
  foreach i of local ivalues {
    gen Xpayavg`rounds'_`ctr' = `var'*(intervention == "`i'")
    label variable Xpayavg`rounds'_`ctr' "Average > 1200 in Rounds `roundstring' * `i'"
    local ctr = `ctr' + 1
  }
}

foreach var of varlist keep2payavggt1200inrounds* {
  local rounds = substr("`var'",strpos("`var'","rounds")+6,5)
  local roundstring = subinstr("`rounds'","_","-",.)
  label variable `var' "Average > 1200 in Rounds `roundstring'"
  local ctr 1
  foreach i of local ivalues {
    gen Xkeep2payavg`rounds'_`ctr' = `var'*(intervention == "`i'")
    label variable Xkeep2payavg`rounds'_`ctr' "Average > 1200 in Rounds `roundstring' * `i'"
    local ctr = `ctr' + 1
  }
}


****************************
*Survey response dependent variable(s).
****************************
if (gametypeid < 8) {
  *Recall of average payment. Was an open text box pre-gametype 8.
  destring responseLastAvgRecall, gen(lastAvgRecall)
  replace lastAvgRecall = lastAvgRecall / `denom'
  summ lastAvgRecall
  *Some people put crazy large numbers. Set them to the 99th pctile.
  *Make sure all cases are from an allocator space of 950-1450 with standard devation 400.
  assert allocatorspace == "uniform|950|1450" & gametypepayrule == "normal|400"
  *Calculate 99th percentile of observed payments, use as the cut.
  centile payments1_16, centile(99)
  local pct99 = `r(c_1)'
  gen lastAvgRecall_above99 = (lastAvgRecall > `pct99')
  label variable lastAvgRecall_above99 "Respondent average recall > 99th pctile of observed"
  cl lastAvgRecall initallocatortype payments1_16 if lastAvgRecall_above99
  *Set lastAvgRecall to pct99 if greater than pct99 unless actual payments were that high.
  replace lastAvgRecall = `pct99' if lastAvgRecall_above99
  *For symmetry, replace people below first at first percentile.
  centile payments1_16, centile(1)
  local pct1 = `r(c_1)'
  gen lastAvgRecall_below1 = (lastAvgRecall  < `pct1')
  label variable lastAvgRecall_below1 "Respondent average recall < 1st pctile of observed"
  cl lastAvgRecall initallocatortype payments1_16 if lastAvgRecall_below1
  replace lastAvgRecall = `pct1' if lastAvgRecall_below1

  label variable lastAvgRecall "Respondent recall of average payout  (in `denom's of tokens)"
}
else {
  di "Code this up when needed."
}
*Satisfaction with Allocator.
label define lastSatisfied -2 "VeryUnsatisfied"  -1 "SomewhatUnsatisfied" 0 "Neither" 1 "SomewhatSatisfied" 2 "VerySatisfied"
encode responseLastSatisfied , gen(lastSatisfied) label(lastSatisfied)
label variable lastSatisfied "Respondent satisfaction with first Allocator"

****************************
*Timing variable(s).
****************************
*Time from start to time of retention decision after round 16.
gen double timestart_clk = clock(timestart,"YMDhms")
format timestart_clk %tc
gen double timekeep_clk  = clock(timekeep,"YMDhms")
format timekeep_clk %tc
gen timetoretention = timekeep_clk - timestart_clk
*Recode into minutes.
replace timetoretention = timetoretention/(1000*60)
label variable timetoretention "Time from start to retention in minutes"

*Time on first instructions page (same point in each survey).
*Doesn't appear I kept track of that.