#
# endBiasPlots-replication.R
#
# Make plots for  three experiements fielded 
# on Mechanical Turk by Huber, Hill, and Lenz in March, 
# April, and May 2011, and the replication experiment fielded
# in February 2012, using data in various subdirectories.
#

rm( list = ls() )
if (.Platform$OS.type == "windows") {
  warning("You'll need to set your working directory here.\n")
  setwd("~")
}
library(foreign)

dotPlotWithBars <- function(dat,success,count,group,ci=.95,txt=T,makePlot=T,...) {
  # Plot aggregated success rates by grouping variable.
  # Arguments.
  #  dat -- data frame.
  #  success -- name of variable counting successes in dat.
  #  count -- name of variable counting cases in dat.
  #  group -- grouping variable to aggregate within and plot.
  #  ci -- level of confidence for confidence interval.
  #  txt -- print point value below points if TRUE.
  #  makePlot -- produce plot.
  #  ... -- additional arguments to plot.
  # Returns.
  #  aggregated data frame; and plots dot chart.
  
  if (any(dat[,success] > dat[,count])) {
    stop("Expecting all success values to be <= count values.\n")
  }
  # Aggregate.
  agg <- aggregate(dat[,c(success,count)],by=list("group"=dat[,group]),sum,na.rm=T)
  agg$rate <- agg[,success] / agg[,count]
  # Calculate standard error.
  agg$se <- sqrt(agg[,'rate']*(1-agg[,'rate'])/agg[,count])
  # Calculate upper and lower ci percent interval values.
  z <- qnorm(1-(1-ci)/2) # Z value for this level of confidence.
  agg$ub <- with(agg, rate + z*se)
  agg$lb <- with(agg, rate - z*se)
  if (makePlot) {
    # Plot.
    plot(x=range(agg[,c('ub','lb')]),y=c(1,nrow(agg)),type='n',axes=F,ann=F,...)
    for (i in 1:nrow(agg)) {
      lines(x=agg[i,c('ub','lb')],y=rep(i,2),col='gray')
    }
    points(x=agg$rate,y=1:nrow(agg),pch=19)
    text(x=agg$rate,y=1:nrow(agg),sprintf("%1.2f",agg$rate),pos=1,cex=.9)
    axis(1)
    axis(2,at=1:nrow(agg),labels=agg$group,las=2,...)
  }
  # Return aggregated frame.
  agg
}

# =======================================
# Plot of Proportion Retaining by lottery intervention.
# Data file created by scripts3-experiments2and3/AnalyzeIncumbentGame-VaryingLottery.do.
# =======================================
dta <- read.dta("scripts-experiments2and3/forR-VaryingLottery.dta",convert.underscore=T)
print(with(dta,table(intervention)))

dta$collapsed.intervention <- with(dta,ifelse(lotteryhi==1,"Lottery Payment 5000",
                                       ifelse(lotterylo==1,"Lottery Payment -5000",
                                       "Lottery Payment 0")))
dta$count <- rep(1,nrow(dta))

# First for the R session.
makePlot <- F
if (.Platform$OS.type == "windows") makePlot <- T
reelect.by.collapse <- dotPlotWithBars(dat=dta,success="keepallocator",count="count",
                        group="collapsed.intervention",ci=.9,txt=T,
                        makePlot=makePlot)
title(xlab="Proportion Retaining Allocator")
reelect.by.all <- dotPlotWithBars(dat=dta,success="keepallocator",count="count",
                        group="intervention",ci=.9,txt=T,
                        makePlot=makePlot)
title(xlab="Proportion Retaining Allocator")
xlim <- range(c(reelect.by.collapse[,c('ub','lb')],reelect.by.all[,c('ub','lb')]))

pdf("graphs/Figure05_ReelectionByLotteryIntervention.pdf",width=11,height=8)                                       
par(mfrow=c(1,2),mar=c(4.1,8.1,1.1,1.1))
reelect.by.collapse <- dotPlotWithBars(dat=dta,success="keepallocator",count="count",
                        group="collapsed.intervention",ci=.95,txt=T,
                        makePlot=makePlot,xlim=xlim,cex.axis=.7)
title(xlab="Proportion Retaining Allocator")
reelect.by.all <- dotPlotWithBars(dat=dta,success="keepallocator",count="count",
                        group="intervention",ci=.95,txt=T,
                        makePlot=makePlot,xlim=xlim,cex.axis=.7)
title(xlab="Proportion Retaining Allocator")
dev.off()

print(reelect.by.collapse)
print(reelect.by.all)

# Proportion tests for each lottery intervention against the other.
cat("P-values on proportion test of reelection rates by lottery interventions:\n")
for (i in 1:nrow(reelect.by.collapse)) {
  if (i == nrow(reelect.by.collapse)) break
  for (j in (i+1):nrow(reelect.by.collapse)) {
    joe <- with(reelect.by.collapse[c(i,j),],prop.test(x=keepallocator,n=count))
    cat(sprintf(" %14s (%1.2f%%) versus %14s (%1.2f%%): %1.3f.\n",
        reelect.by.collapse[i,'group'],100*joe$estimate[1],
        reelect.by.collapse[j,'group'],100*joe$estimate[2],joe$p.value))
  }
}

# test of difference of difference of proportions. since N is greater than 30,
# test statistics sampling distributions approximated by normal.
cat("\nP-value on difference of lottery payments by lottery round:\n")
cat(" Between +5000 and -5000 in round 16:\n")
flag <- reelect.by.all$group %in% c("Lottery Payment -5000, Round 16","Lottery Payment 5000, Round 16")
joe.16 <- with(reelect.by.all[flag,],prop.test(x=keepallocator,n=count))
joe.16$se.hat <- (mean(joe.16$conf.int) - joe.16$conf.int[1])/1.96 # impute standard error.
joe.16$n <- sum(reelect.by.all[flag,'count'])
cat(sprintf(" %1.2f%% versus %1.2f%%: %1.3f.\n",
        100*joe.16$estimate[1],100*joe.16$estimate[2],joe.16$p.value))
cat(" Between +5000 and -5000 in round 8:\n")
flag <- reelect.by.all$group %in% c("Lottery Payment -5000, Round  8","Lottery Payment 5000, Round  8")
joe.8 <- with(reelect.by.all[flag,],prop.test(x=keepallocator,n=count))
joe.8$se.hat <- (mean(joe.8$conf.int) - joe.8$conf.int[1])/1.96 # impute standard error.
joe.8$n <- sum(reelect.by.all[flag,'count'])
cat(sprintf(" %1.2f%% versus %1.2f%%: %1.3f.\n",
        100*joe.8$estimate[1],100*joe.8$estimate[2],joe.8$p.value))
# Standardized z value for difference of means: difference of differences divided by
# standard error on differences.
Z.on.diff <- ( (diff(joe.16$estimate) - diff(joe.8$estimate)) /
               sqrt((joe.16$se.hat^2) + (joe.8$se.hat^2)) )
cat("P-value on diff of diff:",2*(1-pnorm(Z.on.diff)),"\n")

# =======================================
# Proportion Retaining Allocator overall and by experiment by avg > 1200.
# =======================================
dta <- read.dta("scripts-experiments-stacked/forR-Stacked.dta",convert.underscore=T)
dta$source2 <- with(dta,ifelse(source == "Lottery","Experiment  2",
                        ifelse(source == "Prime","Experiment   3","Experiment 1")))
dta$cutpoint <- with(dta,ifelse(payavggt1200inrounds1.16 == 1,"\nAverage > 1200\nin Rounds 1-16",
                          "\nAverage < 1200\nin Rounds 1-16"))
dta$intervention2 <- apply(dta[,c("source2","cutpoint")],1,toString)
dta$count <- rep(1,nrow(dta))

pdf("graphs/Figure01_ReelectionByExperimentAndCutpoint.pdf",width=8,height=7)
par(mfrow=c(1,1),mar=c(4.1,8.1,1.1,1.1))
reelect.by.exper <- dotPlotWithBars(dat=dta,success="keepallocator",count="count",
                        group="intervention2",ci=.95,txt=T,makePlot=T,cex.axis=.9,xlim=c(.55,.91))
title(xlab="Proportion Retaining Allocator")
dev.off()
print(reelect.by.exper)

# =======================================
# Plot bootstrap distributions of relevant coefficients.
# =======================================
boot.files <- dir("boots",pattern="dta")
if (length(boot.files) == 0) stop("No bootstrap distributions found, not making plot.\n")

boot.files <- boot.files[regexpr("Binned",boot.files) == -1]
boots <- list()
for (f in boot.files) {
  boots[[f]] <- read.dta(file.path("boots",f),convert.underscore=T)
}

oneTailedP <- function(x) {
  # Return the proportion of cases l.t. or g.t. zero on same side as mean.
  if (sign(mean(x,na.rm=T)) == 1) {
    return(mean(x<0,na.rm=T))
  } else {
    return(mean(x>0,na.rm=T))
  }
}

pdf("graphs/BootstrapHypothesisDistributions.pdf",width=10,height=7)
cex.main = .85
num.vecs <- sum(unlist(lapply(boots,ncol)))
par(mfrow=c(2,num.vecs/2),mar=c(4.1,2.1,4.1,1.1))
for (model in c("reg","probit")) {
  # Varying instructions models.
  for (v in c('b116','b1316')) {
    for (spec in c("Continuous","Cutpoint")) {
      f <- sprintf("VaryingInstructions%s-%s.dta",spec,model)
      hist(boots[[f]][,v],breaks=20,ann=F,axes=F,freq=F)
      lines(density(boots[[f]][,v]),lwd=2)
      axis(1)
      abline(v=0,lwd=2)
      if (v=='b116') {
        title(main=sprintf("Rounds 1-16*\nInstructions round 12\n%s, %s",spec,
            ifelse(model=="reg","OLS","Probit")),cex.main=cex.main)
      } else {
        title(main=sprintf("Rounds 13-16*\nInstructions round 12\n%s, %s",spec,
            ifelse(model=="reg","OLS","Probit")),cex.main=cex.main)
      }
      title(xlab=sprintf("One-tailed p < %1.2f",oneTailedP(boots[[f]][,v])),line=2)
    }
  }
  # Varying prime models.
  for (v in c('b116','b1316')) {
    for (spec in c("Continuous","Cutpoint")) {
      f <- sprintf("VaryingPrime%s-%s.dta",spec,model)
      hist(boots[[f]][,v],breaks=20,ann=F,axes=F,freq=F)
      lines(density(boots[[f]][,v]),lwd=2)
      axis(1)
      abline(v=0,lwd=2)
      if (v=='b116') {
        title(main=sprintf("Rounds 1-16*\nInformational prime\n%s, %s",spec,
            ifelse(model=="reg","OLS","Probit")),cex.main=cex.main)
      } else {
        title(main=sprintf("Rounds 13-16*\nInformational prime\n%s, %s",spec,
            ifelse(model=="reg","OLS","Probit")),cex.main=cex.main)
      }
      title(xlab=sprintf("One-tailed p < %1.2f",oneTailedP(boots[[f]][,v])),line=2)
    }
  }
}
dev.off()
