**********************************************************
*AnalyzeIncumbentGame-VaryingLotteryExperiment4.do

*Analyze the results of the incumbent game fielded on Mechanical
*Turk by Huber, Hill, and Lenz in February 2012.
*Uses data created by LoadIncumbentGame.do.
**********************************************************

clear
set more off

*Check if model argument has been passed to do file. If
*not, default to reg.
if ("`1'" == "") {
  local model "reg"
}
else {
  local model "`1'"
}

use incumbentGameData-VaryingLotteryExperiment4.dta, clear


*Create intervention variable. THIS IS REQUIRED BY RecodeIncumbentGameData.do.
gen intervention = ""
tab lotterypay lotteryround, mis
replace intervention = "Lottery Payment -5000, Round 16" if lotterypay == -5000 & lotteryround == 16
replace intervention = "Lottery Payment 5000, Round 16" if lotterypay == 5000 & lotteryround == 16
tab intervention, miss

*Specific to lottery analysis: lottery payment indicators irrespective of lottery round.
gen lotteryhi = (lotterypay ==  5000)
gen lotterylo = (lotterypay == -5000)
label variable lotteryhi "Lottery Payment  5000 (rather than -5000)"
label variable lotterylo "Lottery Payment -5000 (rather than 5000)"
tab lotteryhi lotterylo

*Generic recoding of variables.
do ../RecodeIncumbentGameData.do

*Drop an intervention indicator as excluded category, manually.
foreach var of varlist interv_* {
  local vlab : variable label `var'
  if ("`vlab'" == "Lottery Payment -5000, Round  16") {
    di "'`vlab'' is excluded intervention category."
    drop `var'
  }
}

*Indicator for those who responded that the lottery does not inform about Allocator type.
gen understoodlottery = (responsepostComprehen1 == "3Nothing")
tab understoodlottery

*Indicator for those who correctly answered comprehension questions about the Allocator game.
gen understoodgame = (responsepreComprehen2 == "NeitherHigher" & responsepreComprehen1 == "900")
tab understoodgame

*Indicator for those who claim they were not influenced by the lottery.
gen notinfluenced = responsepostComprehen2 == "3No"
tab notinfluenced

****************************
*Simple description of data.
****************************

*Binary indicator for whether payments in round 1-16 over 1200
gen avgover1200=(payments1_16>12)

*Is there a difference in probability of retaining given average over 1200

*yes in entire sample
prtest keepallocator, by(avgover1200)

*Create indicator for correct decision
gen correct=(avgover1200==keepallocator)

*Deviation in payouts from cutpoint of 1200
gen distancefrom1200=abs(payments1_16-12)
label var distancefrom1200 "Abs. value difference between avg. payouts and 1200 (in 100s)"
*So error rate is increasing in distance from 1200
twoway (lowess correct distancefrom1200), scheme(s1mono) ytitle(Proportion Correct Decisions)
regress correct distancefrom1200

*Plot of retention rate by continuous payment average and lottery.
gen dumb = .
replace dumb = 6 in 1
replace dumb = 8 in 2
replace dumb = 10 in 3
replace dumb = 12 in 4
replace dumb = 14 in 5
replace dumb = 16 in 6
replace dumb = 18 in 7
label values dumb payments
twoway (scatter keepallocator dumb, msize(zero) msymbol(none)) (lpoly keepallocator payments1_16 if lotterypay==50, lpattern(solid)) (lpoly keepallocator payments1_16 if lotterypay==-50, lpattern(dash)), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "Win 5000 Tokens" 3 "Lose 5000 Tokens") title("Lottery Outcome", size(medium)))  scheme(s2mono) name(LotteryAvgPaymentEffects, replace) xsize(7.5) ysize(5) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "../graphs/ReelectionByLotteryAndAveragePayExper4.eps", as(eps) preview(off) replace
tab lotterypay if payments1_16 != .

*Same scatter, but only for those who know the lottery payout did not indicate anything
*their allocator.
twoway (scatter keepallocator dumb if understoodlottery == 1, msize(zero) msymbol(none)) (lpoly keepallocator payments1_16 if lotterypay==50 & understoodlottery == 1, lpattern(solid)) (lpoly keepallocator payments1_16 if lotterypay==-50 & understoodlottery == 1, lpattern(dash)), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "Win 5000 Tokens" 3 "Lose 5000 Tokens") title("Lottery Outcome", size(medium)))  scheme(s2mono) name(LotteryAvgPaymentEffects, replace) xsize(7.5) ysize(5) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) 
*note(Limited to respondents who correctly answered lottery comprehension question)
graph export "../graphs/ReelectionByLotteryAndAveragePayExper4-UnderstoodLottery.eps", as(eps) preview(off) replace
tab lotterypay if payments1_16 != . & understoodlottery == 1

*Same scatter, but only for those who comprehend the rules of the game.
twoway (scatter keepallocator dumb if understoodgame == 1, msize(zero) msymbol(none)) (lpoly keepallocator payments1_16 if lotterypay==50 & understoodgame == 1, lpattern(solid)) (lpoly keepallocator payments1_16 if lotterypay==-50 & understoodgame == 1, lpattern(dash)), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "Win 5000 Tokens" 3 "Lose 5000 Tokens") title("Lottery Outcome", size(medium)))  scheme(s2mono) name(LotteryAvgPaymentEffects, replace) xsize(7.5) ysize(5) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white)) 
*note(Limited to respondents who correctly answered game comprehension questions)
graph export "../graphs/ReelectionByLotteryAndAveragePayExper4-UnderstoodGame.eps", as(eps) preview(off) replace
tab lotterypay if payments1_16 != . & understoodgame == 1

*Scatter by lottery and devpayments13_16.
gen finaldevsnegative = devpayments13_16 < -2
gen finaldevspositive = devpayments13_16 > 2
twoway (scatter keepallocator dumb, msize(zero) msymbol(none)) (lpoly keepallocator payments1_16 if lotterypay==50 & finaldevspositive == 1, lpattern(solid)) (lpoly keepallocator payments1_16 if lotterypay==50 & finaldevsnegative == 1, lpattern(solid) lcolor(blue)) (lpoly keepallocator payments1_16 if lotterypay==-50 & finaldevspositive == 1, lpattern(dash)) (lpoly keepallocator payments1_16 if lotterypay==-50 & finaldevsnegative == 1, lpattern(dash) lcolor(blue)), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "Win 5000 Tokens, Positive" 3 "Win 5000 Tokens, Negative" 4 "Lose 5000 Tokens, Positive" 5 "Lose 5000 Tokens, Negative") title("Lottery Outcome, Final Round Deviations", size(medium)))  scheme(s2mono) name(LotteryAvgPaymentEffects, replace) xsize(7.5) ysize(5) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "../graphs/ReelectionByLotteryAndAveragePayAndFinalDevsExper4.eps", as(eps) preview(off) replace
tab lotterypay if payments1_16 != . & understoodgame == 1 & finaldevspositive == 1
tab lotterypay if payments1_16 != . & understoodgame == 1 & finaldevsnegative == 1
tab lotterypay if payments1_16 != . & understoodgame == 1 & finaldevsnegative == 0 & finaldevspositive == 0

****************************
*Paper Appendix Table XX.
****************************
local f "../papertables/TableA07_IrrelevantInfoExper4.out"
*Only interventions.
`model' keepallocator lotteryhi
outreg using "`f'", se ctitle("Allocator Retention, All Participants") bracket rdec(3) 3aster replace

*Only direct effects.
`model' keepallocator payavggt1200inrounds1_16 lotteryhi
outreg using "`f'", se ctitle("Allocator Retention, All Participants") bracket rdec(3) 3aster append

`model' keepallocator payments1_16 lotteryhi
outreg using "`f'", se ctitle("Allocator Retention, All Participants") bracket rdec(3) 3aster append
  *Overall test that respondents instructed later overweight final rounds (in specifications below).
  *To be written out to file sigtable.
  local hypothesis "Allowed an unrelated lottery that affected their welfare to influence their choices"
  local modeltext "OLS"
  if ("`model'" == "probit") local modeltext "Probit"
  *Check to see that file connection sigtable is open.
  local fileconnection 0
  file query
  if (`r(N)' > 0) local fileconnection 1
  local testtext "Coefficient on lottery win is zero"
  local b = _b[lotteryhi]
  test lotteryhi
  local outrow "`hypothesis',`testtext',`modeltext',Continuous,`b',`r(p)'"
  *if (`fileconnection') file write sigtable "`outrow'" _n

*End bias.
`model' keepallocator payavggt1200inrounds1_16 lotteryhi payavggt1200inrounds13_16 
outreg using "`f'", se ctitle("Allocator Retention, All Participants") bracket rdec(3) 3aster append

`model' keepallocator payments1_16 lotteryhi devpayments13_16
outreg using "`f'", se ctitle("Allocator Retention, All Participants") bracket rdec(3) 3aster append

*Understood game.
`model' keepallocator payavggt1200inrounds1_16 lotteryhi payavggt1200inrounds13_16 if understoodgame == 1
outreg using "`f'", se ctitle("Allocator Retention, understood game") bracket rdec(3) 3aster append

`model' keepallocator payments1_16 lotteryhi devpayments13_16 if understoodgame == 1
outreg using "`f'", se ctitle("Allocator Retention, understood game") bracket rdec(3) 3aster append

****************************
*Treatment effect heterogeneity by understanding and stakes.
*Gametype 8 is 50K tokens per dollar, gametype 9 is 25K tokens per dollar.
****************************
local f "../papertables/TableA08_Lottery-ByUnderstandingAndStakes.out"
local repl "replace"
gen higherstakes = gametypeid == 9
label variable higherstakes "Participant had higher stakes"
gen lotteryhiXhigherstakes = lotteryhi*higherstakes
label variable lotteryhiXhigherstakes "Lottery 5000*Higher stakes"
gen payments1_16Xhigherstakes = payments1_16*higherstakes
label variable payments1_16Xhigherstakes "Average Payments Rounds 1-16*Higher stakes"

gen filter = 0
label variable filter "Sample filters"
label define filter 0 " " 1 ", understood lottery" 2 ", understood lottery and game" 3 ", understood lottery and game and was not influenced"
label values filter filter
replace filter = 1 if understoodlottery == 1
replace filter = 2 if understoodlottery == 1 & understoodgame == 1
replace filter = 3 if understoodlottery == 1 & understoodgame == 1 & notinfluenced == 1

forvalues i = 0/2 {
  local slabel: label(filter) `i', strict

  *Payments only.
  `model' keepallocator payments1_16 if filter >= `i'
  *outreg using "`f'", se bracket ctitle("Allocator Retention`slabel'") rdec(3) 3aster `repl'
  *local repl "append"
  *Lottery only.
  `model' keepallocator lotteryhi if filter >= `i'
  *outreg using "`f'", se bracket ctitle("Allocator Retention`slabel'") rdec(3) 3aster `repl'
  *local repl "append"
  *Lottery and payments.
  `model' keepallocator payments1_16 lotteryhi if filter >= `i'
  outreg using "`f'", se bracket ctitle("Allocator Retention`slabel'") rdec(3) 3aster `repl'
  local repl "append"
  *By stakes.
  `model' keepallocator payments1_16 lotteryhi lotteryhiXhigher higherstakes payments1_16Xhigherstakes if filter >= `i'
  lincom lotteryhi + lotteryhiXhigher
  testparm *higherstakes
  outreg using "`f'", se bracket ctitle("Allocator Retention`slabel', by stakes") rdec(3) 3aster addstat("P-value on joint significance of higher stakes terms (two-tailed)",`r(p)') adec(6) `repl'  
}

****************************
*Tabulate game understanding.
****************************
tab responsepreComprehen*, miss cell nokey
tab responsepostComprehen1, miss
bys understoodlottery: tab responsepreComprehen*, cell nokey

****************************
*Save out current data set for R graphic production.
****************************
count
save "forR-VaryingLottery.dta", replace

****************************
*Check on randomization.
****************************
foreach var of varlist interv_* {
  qui `model' `var' pay1-pay16
  testparm pay*
}

*Numbers and dates of recruitment.
qui count
sort timestart_clk
local first = timestart_clk in 1
local last = timestart_clk in `r(N)'
di _n "Recruited `r(N)' participants from " string(`first',"%tc") " to " string(`last',"%tc") "." _n


